attribute vec2 texture0;
attribute vec2 texture1; 
attribute vec2 texture2;
attribute vec2 texture3;

uniform vec4 additionalColor; 
uniform vec4 ambientColor;

uniform mat4 modelViewMatrix;
uniform mat4 modelViewProjectionMatrix; 

uniform float fogStart;
uniform float fogEnd;
uniform vec3 fogColor;

uniform vec3 lightPositions[8];
uniform vec3 diffuseColors[8];

attribute vec4 position;
attribute vec3 normal;

varying vec2 texCoord0;
varying vec2 texCoord1;
varying vec2 texCoord2;
varying vec2 texCoord3;

varying vec4 vertexColor;
varying vec4 fogVertexColor;

const vec4 WHITE = vec4(1.0,1.0,1.0,1.0);

void main(void)
{
	texCoord0=texture0;
	texCoord1=texture1*0.5;
	texCoord2=texture2;
	texCoord3=texture3;
	
	vertexColor = additionalColor+ambientColor;
	
	vec3 vVertex = vec3(modelViewMatrix * position);
	vec3 normalEye   = normalize(modelViewMatrix * vec4(normal, 0.0)).xyz;
	float angle = dot(normalEye, normalize(lightPositions[0] - vVertex));
		
	if (angle > 0.0) {
		vertexColor += vec4(diffuseColors[0] * angle, 0.0);
	}
		
	vertexColor=2.0*vec4(min(WHITE, vertexColor).xyz, 0.5);
	
	float fogWeight = clamp((-vVertex.z - fogStart) / (fogEnd - fogStart), 0.0, 1.0);
	fogVertexColor = vec4(fogColor, 0.0) * fogWeight;
	fogWeight=1.0-fogWeight;
	
	vertexColor*=fogWeight;
	gl_Position = modelViewProjectionMatrix * position;
}