uniform mat4 modelViewMatrix;
uniform mat4 modelViewProjectionMatrix;

uniform vec4 additionalColor;
uniform vec4 ambientColor;

uniform int lightCount;

uniform vec3 lightPositions[8];
uniform vec3 diffuseColors[8];

uniform float fader;
uniform float fogDistance;

uniform float invRadius;

attribute vec4 position;
attribute vec4 tangent;
attribute vec2 texture0;
attribute vec3 normal;

varying vec3 eyeVec;
varying vec2 texCoord;
varying vec4 vertexColor;
varying vec4 diffuseColor;
varying vec3 lVec;
varying float fogWeight;
varying float att;

void main(void)
{
	texCoord = texture0.xy;
	vertexColor=vec4(0,0,0,0);
	
	vec3 normy=normal;
	
	// On some Mali-based GPUs (in the S7 and S9 for example), the last normal of some polygons
	// will be omitted due to a driver bug(?). This happens only in dungeons and it's easy
	// to work around it in this context by recreating the normals here if needed...
	if (length(normy)==0.0) {
		if (position.y>70.0) {
			// Ceiling
			normy=vec3(0.0,-1.0,0.0);
		} else if (position.y<-70.0) {
			// Floor
			normy=vec3(0.0,1.0,0.0);
		} else {
			// Wall
			normy=vec3(1.0,0.0,0.0);
		}
	}
	
	vec3 n = normalize(modelViewMatrix * vec4(normy,0.0)).xyz;
	vec3 t = normalize(modelViewMatrix * vec4(tangent.xyz, 0.0)).xyz;
	
	vec3 b = tangent.w*cross(n, t);
	
	vec3 vVertex = vec3(modelViewMatrix * position);
	vec3 tmpVec = lightPositions[0].xyz - vVertex;

	vec3 lv;
	vec3 ev;

	lv.x = dot(tmpVec, t);
	lv.y = dot(tmpVec, b);
	lv.z = dot(tmpVec, n);

	tmpVec = vVertex*-1.0;
	eyeVec.x = dot(tmpVec, t);
	eyeVec.y = dot(tmpVec, b);
	eyeVec.z = dot(tmpVec, n);
	
	eyeVec=normalize(eyeVec);
	diffuseColor=vec4(diffuseColors[0],0);
	
	float distSqr = dot(lv, lv);
	
	att = clamp(1.0 - invRadius * sqrt(distSqr), 0.0, 1.0);
	lVec = lv * inversesqrt(distSqr);
	
	if (lightCount>1) {
	
		tmpVec = lightPositions[1] - vVertex;
		vec3 normalEye   = normalize(modelViewMatrix * vec4(normy, 0.0)).xyz;
		
		float angle = dot(normalEye, normalize(tmpVec));
		
		if (angle > 0.0) {
			vertexColor += vec4(diffuseColors[1] * (angle * (1.0- (min(fader, length(tmpVec)+0.1)/fader))), 0);
		} //else if (length(normy)==0.0) {
		//	vertexColor += vec4(0.0,1.0,0.0,0.0);
		//}
	
		if (lightCount>2) {
		 	tmpVec = lightPositions[2] - vVertex;
			angle = dot(normalEye, normalize(tmpVec));
		
			if (angle > 0.0) {
				vertexColor += vec4(diffuseColors[2] * (angle * (1.0- (min(fader, length(tmpVec)+0.1)/fader))), 0);
			}
			if (lightCount>3) {
				tmpVec = lightPositions[3] - vVertex;
				angle = dot(normalEye, normalize(tmpVec));
			
				if (angle > 0.0) {
					vertexColor += vec4(diffuseColors[3] * (angle * (1.0- (min(fader, length(tmpVec)+0.1)/fader))), 0);
				}
			
				if (lightCount>4) {
					tmpVec = lightPositions[4] - vVertex;
					angle = dot(normalEye, normalize(tmpVec));
				
					if (angle > 0.0) {
						vertexColor += vec4(diffuseColors[4] * (angle * (1.0- (min(fader, length(tmpVec)+0.1)/fader))), 0);
					}
				
					if (lightCount>5) {
						tmpVec = lightPositions[5] - vVertex;
						angle = dot(normalEye, normalize(tmpVec));
						
						if (angle > 0.0) {
							vertexColor += vec4(diffuseColors[5] * (angle * (1.0- (min(fader, length(tmpVec)+0.1)/fader))), 0);
						}
						
						if (lightCount>6) {
						 	tmpVec = lightPositions[6] - vVertex;
							angle = dot(normalEye, normalize(tmpVec));
							
							if (angle > 0.0) {
								vertexColor += vec4(diffuseColors[6] * (angle * (1.0- (min(fader, length(tmpVec)+0.1)/fader))), 0);
							}
							
							if (lightCount>7) {
								tmpVec = lightPositions[7] - vVertex;
								angle = dot(normalEye, normalize(tmpVec));
								
								if (angle > 0.0) {
									vertexColor += vec4(diffuseColors[7] * (angle * (1.0- (min(fader, length(tmpVec)+0.1)/fader))), 0);
								}
							}
						}
					}
				}
			}
		}
	}
	
	fogWeight = 2.0*(1.0-clamp((-vVertex.z - (fogDistance-280.0)) / (280.0), 0.0, 1.0));
	gl_Position = modelViewProjectionMatrix * position;
}