attribute vec2 texture0;

uniform vec4 additionalColor; 
uniform vec4 ambientColor;

uniform mat4 modelViewMatrix;
uniform mat4 modelViewProjectionMatrix; 

uniform float fogStart;
uniform float fogEnd;
uniform vec3 fogColor;

uniform vec3 lightPositions[8];
uniform vec3 diffuseColors[8];
uniform vec3 specularColors[8];

uniform float shininess;
uniform float alpha;
uniform float flip;

attribute vec4 position;
attribute vec3 normal;

varying vec2 texCoord0;

varying vec4 vertexColor;
varying vec4 fogVertexColor;

const vec4 WHITE = vec4(1.0,1.0,1.0,1.0);

void main(void)
{
	texCoord0=texture0;
	
	vec4 pos=position;
	vec3 norm=normal;
	pos.x=flip*pos.x;
	norm.x=flip*norm.x;
	
	vertexColor = additionalColor+ambientColor;
	
	vec3 vVertex = vec3(modelViewMatrix * pos);
	vec3 normalEye   = normalize(modelViewMatrix * vec4(norm, 0.0)).xyz;
	float angle = dot(normalEye, normalize(lightPositions[0] - vVertex));
		
	if (angle > 0.0) {
		vertexColor += vec4(diffuseColors[0] * angle + specularColors[0] * pow(angle, shininess),0.0);
	}
		
	vertexColor=2.0*vec4(min(WHITE, vertexColor).xyz, alpha*0.5);
	
	float fogWeight = clamp((-vVertex.z - fogStart) / (fogEnd - fogStart), 0.0, 1.0);
	fogVertexColor = vec4(fogColor, 0.0) * fogWeight;
	fogWeight=1.0-fogWeight;
	
	vertexColor*=fogWeight;
	gl_Position = modelViewProjectionMatrix * pos;
}