attribute vec2 texture0;
attribute vec4 position;
attribute vec3 normal;

uniform mat4 modelViewMatrix;
uniform mat4 modelViewProjectionMatrix; 

uniform float fogStart;
uniform float fogEnd;
uniform vec3 fogColor;

uniform float alpha;

uniform vec3 lightPositions[8];
uniform vec3 diffuseColors[8];
uniform vec3 specularColors[8];

uniform float flip;

varying vec3 normalVec, lightDir, eyeVec;
varying vec2 texCoord;	
varying vec4 vertexColor;
varying vec4 diffuseColor;

const vec4 WHITE = vec4(1.0,1.0,1.0,1.0);

uniform int lightCount;


void main(void)
{	
	vec4 pos=position;
	vec3 norm=normal;
	pos.x=flip*pos.x;
	norm.x=flip*norm.x;
	
	normalVec = normalize(modelViewMatrix * vec4(norm, 0.0)).xyz;
	diffuseColor=vec4(diffuseColors[0] ,1.0);
		
	vec3 vVertex = vec3(modelViewMatrix * pos);
	lightDir = vec3(lightPositions[0] - vVertex);
	eyeVec = -vVertex;
	
	gl_Position = modelViewProjectionMatrix * pos;
	texCoord=texture0;
	
	vertexColor=vec4(0.0, 0.0, 0.0, 0.0);
	if (lightCount>1) {
		vec3 vNormal = normalize(modelViewMatrix * vec4(norm, 0.0)).xyz;
		vec3 tmpVec = lightPositions[1] - vVertex;
		float angle = dot(vNormal, normalize(tmpVec));

		if (angle > 0.0) {
			vertexColor += vec4(diffuseColors[1] * angle, 0.0);
		}

		if (lightCount>2) {
			tmpVec = lightPositions[2] - vVertex;
			angle = dot(vNormal, normalize(tmpVec));

			if (angle > 0.0) {
				vertexColor += vec4(diffuseColors[2] * angle, 0.0);
			}
		}
	}
	
	vertexColor=vec4(min(WHITE, vertexColor).xyz, alpha);
}