attribute vec2 texture0;
attribute vec4 position;
attribute vec3 normal;

uniform vec4 additionalColor; 
uniform vec4 ambientColor;

uniform mat4 modelViewMatrix;
uniform mat4 modelViewProjectionMatrix; 

uniform float fogStart;
uniform float fogEnd;
uniform vec3 fogColor;

uniform vec3 lightPositions[8];
uniform vec3 diffuseColors[8];

uniform float alpha;
uniform float random;
uniform float muly;

varying vec2 texCoord0;
varying vec4 vertexColor;
varying vec4 fogVertexColor;

const vec4 WHITE = vec4(1.0,1.0,1.0,1.0);

void main(void)
{
	texCoord0=texture0;
	
	vertexColor = additionalColor+ambientColor;
	
	vec3 vVertex = vec3(modelViewMatrix * position);
	vec3 normalEye   = normalize(modelViewMatrix * vec4(normal, 0.0)).xyz;
	float angle = dot(normalEye, normalize(lightPositions[0] - vVertex));
		
	if (angle > 0.0) {
		vertexColor += vec4(diffuseColors[0] * angle,0.0);
	}
		
	vertexColor=2.0*vec4(min(WHITE, vertexColor).xyz, alpha*0.5);
	
	float fogWeight = clamp((-vVertex.z - fogStart) / (fogEnd - fogStart), 0.0, 1.0);
	fogVertexColor = vec4(fogColor,0.0) * fogWeight;
	fogWeight = (1.0-fogWeight);
	
	vec4 pos= modelViewProjectionMatrix * position;
	
	vertexColor*=fogWeight;
	
	if (texCoord0.y<0.5) {
	    if (pos.z<2000.0) {
			float cosy=cos(mod(random*0.005+position.z*0.5, 6.2831))*muly;
			pos.x=pos.x+cosy;
			pos.y=pos.y-cosy;
		}
		vertexColor*=1.15;
	}
	
	gl_Position = pos;
}