uniform mat4 modelViewMatrix;
uniform mat4 modelViewProjectionMatrix;

uniform vec4 additionalColor;
uniform vec4 ambientColor;

uniform float alpha;
uniform float shininess;
uniform bool useColors;

uniform int lightCount;

uniform vec3 lightPositions[8];
uniform vec3 diffuseColors[8];

attribute vec4 position;
attribute vec3 normal;
attribute vec4 color;
attribute vec2 texture0;
attribute vec2 texture1;

varying vec2 texCoord[2];
varying vec4 vertexColor;


const vec4 WHITE = vec4(1,1,1,1);

void main() {

	bool dungeon=ambientColor.r==0.0;

	texCoord[0] = texture0.xy;	
	texCoord[1] = texture1.xy;
	
	vec4 vertexPos = modelViewMatrix * position;
	vertexColor = ambientColor + additionalColor;

	if (lightCount>0) {
	
		vec3 normalEye   = normalize(modelViewMatrix * vec4(normal, 0.0)).xyz;
		float angle = dot(normalEye, normalize(lightPositions[0] - vertexPos.xyz));
			
		if (!dungeon && angle > 0.0) {
			vertexColor += vec4(diffuseColors[0] * angle, 1);
		}
		
		if (lightCount>1) {
			angle = dot(normalEye, normalize(lightPositions[1] - vertexPos.xyz));
			
			if (angle > 0.0) {
				vertexColor += vec4(diffuseColors[1] * angle, 1);
			}
			
			if (lightCount>2) {
				angle = dot(normalEye, normalize(lightPositions[2] - vertexPos.xyz));
				
				if (angle > 0.0) {
					vertexColor += vec4(diffuseColors[2] * angle, 1);
				}
				
				if (lightCount>3) {
					angle = dot(normalEye, normalize(lightPositions[3] - vertexPos.xyz));
					
					if (angle > 0.0) {
						vertexColor += vec4(diffuseColors[3] * angle, 1);
					}
					
					if (lightCount>4) {
						angle = dot(normalEye, normalize(lightPositions[4] - vertexPos.xyz));
						
						if (angle > 0.0) {
							vertexColor += vec4(diffuseColors[4] * angle, 1);
						}
						
						if (lightCount>5) {
							angle = dot(normalEye, normalize(lightPositions[5] - vertexPos.xyz));
							
							if (angle > 0.0) {
								vertexColor += vec4(diffuseColors[5] * angle, 1);
							}
							
							if (lightCount>6) {
								angle = dot(normalEye, normalize(lightPositions[6] - vertexPos.xyz));
								
								if (angle > 0.0) {
									vertexColor += vec4(diffuseColors[6] * angle, 1);
								}
								if (lightCount>7) {
									angle = dot(normalEye, normalize(lightPositions[7] - vertexPos.xyz));
									
									if (angle > 0.0) {
										vertexColor += vec4(diffuseColors[7] * angle, 1);
									}
								}
							}
						}
					}
				}
			}
		}
	}
	
	vertexColor=vec4((dungeon?1.0:2.0)*min(WHITE, vertexColor).xyz, alpha);
	
	if (useColors) {
		vertexColor *= color;
	}
	
	gl_Position = modelViewProjectionMatrix * position;
}